@@ -46,3 +46,23 @@ class GuestsModel(DynamicDocument):
     subscriptions = ListField(DictField())
     taxInfo = DictField()
     telephones = DictField()
+
+
+class GuestsModelV2(DynamicDocument):
+    meta = {'collection': 'guests'}
+
+    _id = StringField(primary_key=True)
+    idObj = EmbeddedDocumentField(ProfileIDObject)
+    profileType = StringField()
+    title = StringField()
+    firstName = StringField()
+    lastName = StringField()
+    datesAndDurations = DictField()
+    address = DictField()
+    contactInfo = DictField()
+    privacyInfo = DictField()
+    documents = DictField()
+    metaInfo = DictField()
+    company = DictField()
+    registeredProperty = StringField()
+    auraRecordUpdatedOn = DateTimeField()
