@@ -244,14 +244,21 @@ class ReservationSync:
             return result
 
     def _transform_guest_profile(self, record):
-        countryCode = country_name_to_country_alpha2(
-            next((x['name'] for x in COUNTRIES if x['id'] == record.get('countryId')), ''))
-        if countryCode is None:
+        countryCode = ''
+        nationalityCode = ''
+        try:
+            countryCode = country_name_to_country_alpha2(
+                next((x['name'] for x in COUNTRIES if x['id'] == record.get('countryId')), ''))
+        except Exception as e:
             logging.error(f'No countryCode found for {record.get("countryId")}')
-        nationalityCode = country_name_to_country_alpha2(
-            next((x['name'] for x in COUNTRIES if x['id'] == record.get('nationalityId')), ''))
-        if nationalityCode is None:
-            logging.error(f'No countryCode found for {record.get("nationalityId")}')
+            logging.error(e)
+        try:
+            nationalityCode = country_name_to_country_alpha2(
+                next((x['name'] for x in COUNTRIES if x['id'] == record.get('nationalityId')), ''))
+        except Exception as e:
+            logging.error(f'No nationalityCode found for {record.get("nationalityId")}')
+            logging.error(e)
+
         hotelId = self.mongo.get_collection(self.mongo.PROPERTY_COLLECTION).find_one({'primaryDetails.propertyId': str(record.get('propertyId'))}, {'_id': 1})
         hotelId = hotelId if hotelId else '0'
         guest = GuestsModelV2(
